pub enum SingularKind {
Scalar(ScalarType),
Enum(EnumIndex),
Message(MessageIndex),
}Expand description
Variants
Scalar(ScalarType)
A scalar value.
Enum(EnumIndex)
An enum value, referencing an enum in the pool.
Message(MessageIndex)
A message value, referencing a message in the pool.