CodeGeneratorRequest

Struct CodeGeneratorRequest 

pub struct CodeGeneratorRequest {
    pub file_to_generate: Vec<String>,
    pub parameter: Option<String>,
    pub proto_file: Vec<FileDescriptorProto>,
    pub source_file_descriptors: Vec<FileDescriptorProto>,
    pub compiler_version: MessageField<Version, Inline<Version>>,
    /* private fields */
}
An encoded CodeGeneratorRequest is written to the plugin’s stdin.

Fields

file_to_generate: Vec<String>

The .proto files that were explicitly listed on the command-line. The code generator should generate code only for these files. Each file’s descriptor will be included in proto_file, below.

Field 1: file_to_generate

parameter: Option<String>

The generator parameter passed on the command-line.

Field 2: parameter

proto_file: Vec<FileDescriptorProto>

FileDescriptorProtos for all files in files_to_generate and everything they import. The files will appear in topological order, so each file appears before any file that imports it.

Note: the files listed in files_to_generate will include runtime-retention options only, but all other files will include source-retention options. The source_file_descriptors field below is available in case you need source-retention options for files_to_generate.

protoc guarantees that all proto_files will be written after the fields above, even though this is not technically guaranteed by the protobuf wire format. This theoretically could allow a plugin to stream in the FileDescriptorProtos and handle them one by one rather than read the entire set into memory at once. However, as of this writing, this is not similarly optimized on protoc’s end – it will store all fields in memory at once before sending them to the plugin.

Type names of fields and extensions in the FileDescriptorProto are always fully qualified.

Field 15: proto_file

source_file_descriptors: Vec<FileDescriptorProto>

File descriptors with all options, including source-retention options. These descriptors are only provided for the files listed in files_to_generate.

Field 17: source_file_descriptors

compiler_version: MessageField<Version, Inline<Version>>

The version number of protocol compiler.

Field 3: compiler_version

Implementations

Source

impl CodeGeneratorRequest

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.compiler.CodeGeneratorRequest"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>

Source

impl CodeGeneratorRequest

pub fn with_parameter(self, value: impl Into<String>) -> Self

Sets Self::parameter to Some(value), consuming and returning self.