CodeGeneratorResponse

Struct CodeGeneratorResponse 

pub struct CodeGeneratorResponse {
    pub error: Option<String>,
    pub supported_features: Option<u64>,
    pub minimum_edition: Option<i32>,
    pub maximum_edition: Option<i32>,
    pub file: Vec<File>,
    /* private fields */
}
The plugin writes an encoded CodeGeneratorResponse to stdout.

Fields

error: Option<String>

Error message. If non-empty, code generation failed. The plugin process should exit with status code zero even if it reports an error in this way.

This should be used to indicate errors in .proto files which prevent the code generator from generating correct code. Errors which indicate a problem in protoc itself – such as the input CodeGeneratorRequest being unparseable – should be reported by writing a message to stderr and exiting with a non-zero status code.

Field 1: error

supported_features: Option<u64>

A bitmask of supported features that the code generator supports. This is a bitwise “or” of values from the Feature enum.

Field 2: supported_features

minimum_edition: Option<i32>

The minimum edition this plugin supports. This will be treated as an Edition enum, but we want to allow unknown values. It should be specified according the edition enum value, not the edition number. Only takes effect for plugins that have FEATURE_SUPPORTS_EDITIONS set.

Field 3: minimum_edition

maximum_edition: Option<i32>

The maximum edition this plugin supports. This will be treated as an Edition enum, but we want to allow unknown values. It should be specified according the edition enum value, not the edition number. Only takes effect for plugins that have FEATURE_SUPPORTS_EDITIONS set.

Field 4: maximum_edition

file: Vec<File>

Field 15: file

Implementations

Source

impl CodeGeneratorResponse

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.compiler.CodeGeneratorResponse"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>

Source

impl CodeGeneratorResponse

pub fn with_error(self, value: impl Into<String>) -> Self

Sets Self::error to Some(value), consuming and returning self.

pub fn with_supported_features(self, value: u64) -> Self

Sets Self::supported_features to Some(value), consuming and returning self.

pub fn with_minimum_edition(self, value: i32) -> Self

Sets Self::minimum_edition to Some(value), consuming and returning self.

pub fn with_maximum_edition(self, value: i32) -> Self

Sets Self::maximum_edition to Some(value), consuming and returning self.