SymbolVisibility

Enum SymbolVisibility 

#[repr(i32)]
pub enum SymbolVisibility { VISIBILITY_UNSET = 0, VISIBILITY_LOCAL = 1, VISIBILITY_EXPORT = 2, }
Describes the ‘visibility’ of a symbol with respect to the proto import system. Symbols can only be imported when the visibility rules do not prevent it (ex: local symbols cannot be imported). Visibility modifiers can only set on message and enum as they are the only types available to be referenced from other files.

Variants



VISIBILITY_UNSET = 0



VISIBILITY_LOCAL = 1



VISIBILITY_EXPORT = 2

Implementations

Source

impl SymbolVisibility

pub const VisibilityUnset: Self = Self::VISIBILITY_UNSET

Idiomatic alias for Self::VISIBILITY_UNSET; Debug prints the variant name.

pub const VisibilityLocal: Self = Self::VISIBILITY_LOCAL

Idiomatic alias for Self::VISIBILITY_LOCAL; Debug prints the variant name.

pub const VisibilityExport: Self = Self::VISIBILITY_EXPORT

Idiomatic alias for Self::VISIBILITY_EXPORT; Debug prints the variant name.