pub struct Declaration {
pub number: Option<i32>,
pub full_name: Option<String>,
pub type: Option<String>,
pub reserved: Option<bool>,
pub repeated: Option<bool>,
/* private fields */
}Fields
number: Option<i32>The extension number declared within the extension range.
Field 1: number
full_name: Option<String>The fully-qualified name of the extension field. There must be a leading dot in front of the full name.
Field 2: full_name
type: Option<String>The fully-qualified type name of the extension field. Unlike Metadata.type, Declaration.type must have a leading dot for messages and enums.
Field 3: type
reserved: Option<bool>If true, indicates that the number is reserved in the extension range, and any extension field with the number will fail to compile. Set this when a declared extension field is deleted.
Field 5: reserved
repeated: Option<bool>If true, indicates that the extension must be defined as repeated. Otherwise the extension must be defined as optional.
Field 6: repeated
Implementations
Sourceimpl Declaration
impl Declaration
Sourceimpl Declaration
impl Declaration
Sourcepub fn with_number(self, value: i32) -> Self
pub fn with_number(self, value: i32) -> Self
Sets Self::number to Some(value), consuming and returning self.
Sourcepub fn with_full_name(self, value: impl Into<String>) -> Self
pub fn with_full_name(self, value: impl Into<String>) -> Self
Sets Self::full_name to Some(value), consuming and returning self.
Sourcepub fn with_type(self, value: impl Into<String>) -> Self
pub fn with_type(self, value: impl Into<String>) -> Self
Sets [Self::r#type] to Some(value), consuming and returning self.
Sourcepub fn with_reserved(self, value: bool) -> Self
pub fn with_reserved(self, value: bool) -> Self
Sets Self::reserved to Some(value), consuming and returning self.
Sourcepub fn with_repeated(self, value: bool) -> Self
pub fn with_repeated(self, value: bool) -> Self
Sets Self::repeated to Some(value), consuming and returning self.