pub struct Annotation {
pub path: Vec<i32>,
pub source_file: Option<String>,
pub begin: Option<i32>,
pub end: Option<i32>,
pub semantic: Option<Semantic>,
/* private fields */
}Fields
path: Vec<i32>Identifies the element in the original source .proto file. This field is formatted the same as SourceCodeInfo.Location.path.
Field 1: path
source_file: Option<String>Identifies the filesystem path to the original source .proto.
Field 2: source_file
begin: Option<i32>Identifies the starting offset in bytes in the generated code that relates to the identified object.
Field 3: begin
end: Option<i32>Identifies the ending offset in bytes in the generated code that relates to the identified object. The end offset should be one past the last relevant byte (so the length of the text = end - begin).
Field 4: end
semantic: Option<Semantic>Field 5: semantic
Implementations
Sourceimpl Annotation
impl Annotation
Sourceimpl Annotation
impl Annotation
Sourcepub fn with_source_file(self, value: impl Into<String>) -> Self
pub fn with_source_file(self, value: impl Into<String>) -> Self
Sets Self::source_file to Some(value), consuming and returning self.
Sourcepub fn with_begin(self, value: i32) -> Self
pub fn with_begin(self, value: i32) -> Self
Sets Self::begin to Some(value), consuming and returning self.
Sourcepub fn with_end(self, value: i32) -> Self
pub fn with_end(self, value: i32) -> Self
Sets Self::end to Some(value), consuming and returning self.
Sourcepub fn with_semantic(self, value: impl Into<Semantic>) -> Self
pub fn with_semantic(self, value: impl Into<Semantic>) -> Self
Sets Self::semantic to Some(value), consuming and returning self.