pub struct EnumValueOptions {
pub deprecated: Option<bool>,
pub features: MessageField<FeatureSet, Inline<FeatureSet>>,
pub debug_redact: Option<bool>,
pub feature_support: MessageField<FeatureSupport, Inline<FeatureSupport>>,
pub uninterpreted_option: Vec<UninterpretedOption>,
/* private fields */
}Fields
deprecated: Option<bool>Is this enum value deprecated? Depending on the target platform, this can emit Deprecated annotations for the enum value, or it will be completely ignored; in the very least, this is a formalization for deprecating enum values.
Field 1: deprecated
features: MessageField<FeatureSet, Inline<FeatureSet>>Any features defined in the specific edition. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.
Field 2: features
debug_redact: Option<bool>Indicate that fields annotated with this enum value should not be printed out when using debug formats, e.g. when the field contains sensitive credentials.
Field 3: debug_redact
feature_support: MessageField<FeatureSupport, Inline<FeatureSupport>>Information about the support window of a feature value.
Field 4: feature_support
uninterpreted_option: Vec<UninterpretedOption>The parser stores options it doesn’t recognize here. See above.
Field 999: uninterpreted_option
Implementations
Sourceimpl EnumValueOptions
impl EnumValueOptions
Sourcepub fn with_deprecated(self, value: bool) -> Self
pub fn with_deprecated(self, value: bool) -> Self
Sets Self::deprecated to Some(value), consuming and returning self.
Sourcepub fn with_debug_redact(self, value: bool) -> Self
pub fn with_debug_redact(self, value: bool) -> Self
Sets Self::debug_redact to Some(value), consuming and returning self.