pub struct ExtensionRangeOptions {
pub uninterpreted_option: Vec<UninterpretedOption>,
pub declaration: Vec<Declaration>,
pub features: MessageField<FeatureSet>,
pub verification: Option<VerificationState>,
/* private fields */
}Fields
uninterpreted_option: Vec<UninterpretedOption>The parser stores options it doesn’t recognize here. See above.
Field 999: uninterpreted_option
declaration: Vec<Declaration>For external users: DO NOT USE. We are in the process of open sourcing extension declaration and executing internal cleanups before it can be used externally.
Field 2: declaration
features: MessageField<FeatureSet>Any features defined in the specific edition.
Field 50: features
verification: Option<VerificationState>The verification state of the range. TODO: flip the default to DECLARATION once all empty ranges are marked as UNVERIFIED.
Field 3: verification
Implementations
Sourceimpl ExtensionRangeOptions
impl ExtensionRangeOptions
Sourcepub fn with_verification(self, value: impl Into<VerificationState>) -> Self
pub fn with_verification(self, value: impl Into<VerificationState>) -> Self
Sets Self::verification to Some(value), consuming and returning self.