pub struct FeatureSet {
pub field_presence: Option<FieldPresence>,
pub enum_type: Option<EnumType>,
pub repeated_field_encoding: Option<RepeatedFieldEncoding>,
pub utf8_validation: Option<Utf8Validation>,
pub message_encoding: Option<MessageEncoding>,
pub json_format: Option<JsonFormat>,
pub enforce_naming_style: Option<EnforceNamingStyle>,
pub default_symbol_visibility: Option<DefaultSymbolVisibility>,
/* private fields */
}Expand description
=================================================================== Features
TODO Enums in C++ gencode (and potentially other languages) are not well scoped. This means that each of the feature enums below can clash with each other. The short names we’ve chosen maximize call-site readability, but leave us very open to this scenario. A future feature will be designed and implemented to handle this, hopefully before we ever hit a conflict here.
Fields
field_presence: Option<FieldPresence>Field 1: field_presence
enum_type: Option<EnumType>Field 2: enum_type
repeated_field_encoding: Option<RepeatedFieldEncoding>Field 3: repeated_field_encoding
utf8_validation: Option<Utf8Validation>Field 4: utf8_validation
message_encoding: Option<MessageEncoding>Field 5: message_encoding
json_format: Option<JsonFormat>Field 6: json_format
enforce_naming_style: Option<EnforceNamingStyle>Field 7: enforce_naming_style
default_symbol_visibility: Option<DefaultSymbolVisibility>Field 8: default_symbol_visibility
Implementations
Sourceimpl FeatureSet
impl FeatureSet
Sourceimpl FeatureSet
impl FeatureSet
Sourcepub fn with_field_presence(self, value: impl Into<FieldPresence>) -> Self
pub fn with_field_presence(self, value: impl Into<FieldPresence>) -> Self
Sets Self::field_presence to Some(value), consuming and returning self.
Sourcepub fn with_enum_type(self, value: impl Into<EnumType>) -> Self
pub fn with_enum_type(self, value: impl Into<EnumType>) -> Self
Sets Self::enum_type to Some(value), consuming and returning self.
Sourcepub fn with_repeated_field_encoding(
self,
value: impl Into<RepeatedFieldEncoding>,
) -> Self
pub fn with_repeated_field_encoding( self, value: impl Into<RepeatedFieldEncoding>, ) -> Self
Sets Self::repeated_field_encoding to Some(value), consuming and returning self.
Sourcepub fn with_utf8_validation(self, value: impl Into<Utf8Validation>) -> Self
pub fn with_utf8_validation(self, value: impl Into<Utf8Validation>) -> Self
Sets Self::utf8_validation to Some(value), consuming and returning self.
Sourcepub fn with_message_encoding(self, value: impl Into<MessageEncoding>) -> Self
pub fn with_message_encoding(self, value: impl Into<MessageEncoding>) -> Self
Sets Self::message_encoding to Some(value), consuming and returning self.
Sourcepub fn with_json_format(self, value: impl Into<JsonFormat>) -> Self
pub fn with_json_format(self, value: impl Into<JsonFormat>) -> Self
Sets Self::json_format to Some(value), consuming and returning self.
Sourcepub fn with_enforce_naming_style(
self,
value: impl Into<EnforceNamingStyle>,
) -> Self
pub fn with_enforce_naming_style( self, value: impl Into<EnforceNamingStyle>, ) -> Self
Sets Self::enforce_naming_style to Some(value), consuming and returning self.
Sourcepub fn with_default_symbol_visibility(
self,
value: impl Into<DefaultSymbolVisibility>,
) -> Self
pub fn with_default_symbol_visibility( self, value: impl Into<DefaultSymbolVisibility>, ) -> Self
Sets Self::default_symbol_visibility to Some(value), consuming and returning self.