pub struct FeatureSetDefaults {
pub defaults: Vec<FeatureSetEditionDefault>,
pub minimum_edition: Option<Edition>,
pub maximum_edition: Option<Edition>,
/* private fields */
}Expand description
A compiled specification for the defaults of a set of features. These messages are generated from FeatureSet extensions and can be used to seed feature resolution. The resolution with this object becomes a simple search for the closest matching edition, followed by proto merges.
Fields
defaults: Vec<FeatureSetEditionDefault>Field 1: defaults
minimum_edition: Option<Edition>The minimum supported edition (inclusive) when this was constructed. Editions before this will not have defaults.
Field 4: minimum_edition
maximum_edition: Option<Edition>The maximum known edition (inclusive) when this was constructed. Editions after this will not have reliable defaults.
Field 5: maximum_edition
Implementations
Sourceimpl FeatureSetDefaults
impl FeatureSetDefaults
Sourcepub fn with_minimum_edition(self, value: impl Into<Edition>) -> Self
pub fn with_minimum_edition(self, value: impl Into<Edition>) -> Self
Sets Self::minimum_edition to Some(value), consuming and returning self.
Sourcepub fn with_maximum_edition(self, value: impl Into<Edition>) -> Self
pub fn with_maximum_edition(self, value: impl Into<Edition>) -> Self
Sets Self::maximum_edition to Some(value), consuming and returning self.