pub struct FieldDescriptorProto {
pub name: Option<String>,
pub number: Option<i32>,
pub label: Option<Label>,
pub type: Option<Type>,
pub type_name: Option<String>,
pub extendee: Option<String>,
pub default_value: Option<String>,
pub oneof_index: Option<i32>,
pub json_name: Option<String>,
pub options: MessageField<FieldOptions>,
pub proto3_optional: Option<bool>,
/* private fields */
}Expand description
Describes a field within a message.
Fields
name: Option<String>Field 1: name
number: Option<i32>Field 3: number
label: Option<Label>Field 4: label
type: Option<Type>If type_name is set, this need not be set. If both this and type_name are set, this must be one of TYPE_ENUM, TYPE_MESSAGE or TYPE_GROUP.
Field 5: type
type_name: Option<String>For message and enum types, this is the name of the type. If the name starts with a ‘.’, it is fully-qualified. Otherwise, C++-like scoping rules are used to find the type (i.e. first the nested types within this message are searched, then within the parent, on up to the root namespace).
Field 6: type_name
extendee: Option<String>For extensions, this is the name of the type being extended. It is resolved in the same manner as type_name.
Field 2: extendee
default_value: Option<String>For numeric types, contains the original text representation of the value. For booleans, “true” or “false”. For strings, contains the default text contents (not escaped in any way). For bytes, contains the C escaped value. All bytes >= 128 are escaped.
Field 7: default_value
oneof_index: Option<i32>If set, gives the index of a oneof in the containing type’s oneof_decl list. This field is a member of that oneof.
Field 9: oneof_index
json_name: Option<String>JSON name of this field. The value is set by protocol compiler. If the user has set a “json_name” option on this field, that option’s value will be used. Otherwise, it’s deduced from the field’s name by converting it to camelCase.
Field 10: json_name
options: MessageField<FieldOptions>Field 8: options
proto3_optional: Option<bool>If true, this is a proto3 “optional”. When a proto3 field is optional, it tracks presence regardless of field type.
When proto3_optional is true, this field must belong to a oneof to signal to old proto3 clients that presence is tracked for this field. This oneof is known as a “synthetic” oneof, and this field must be its sole member (each proto3 optional field gets its own synthetic oneof). Synthetic oneofs exist in the descriptor only, and do not generate any API. Synthetic oneofs must be ordered after all “real” oneofs.
For message fields, proto3_optional doesn’t create any semantic change, since non-repeated message fields always track presence. However it still indicates the semantic detail of whether the user wrote “optional” or not. This can be useful for round-tripping the .proto file. For consistency we give message fields a synthetic oneof also, even though it is not required to track presence. This is especially important because the parser can’t tell if a field is a message or an enum, so it must always create a synthetic oneof.
Proto2 optional fields do not set this flag, because they already indicate
optional with LABEL_OPTIONAL.
Field 17: proto3_optional
Implementations
Sourceimpl FieldDescriptorProto
impl FieldDescriptorProto
Sourcepub fn with_name(self, value: impl Into<String>) -> Self
pub fn with_name(self, value: impl Into<String>) -> Self
Sets Self::name to Some(value), consuming and returning self.
Sourcepub fn with_number(self, value: i32) -> Self
pub fn with_number(self, value: i32) -> Self
Sets Self::number to Some(value), consuming and returning self.
Sourcepub fn with_label(self, value: impl Into<Label>) -> Self
pub fn with_label(self, value: impl Into<Label>) -> Self
Sets Self::label to Some(value), consuming and returning self.
Sourcepub fn with_type(self, value: impl Into<Type>) -> Self
pub fn with_type(self, value: impl Into<Type>) -> Self
Sets [Self::r#type] to Some(value), consuming and returning self.
Sourcepub fn with_type_name(self, value: impl Into<String>) -> Self
pub fn with_type_name(self, value: impl Into<String>) -> Self
Sets Self::type_name to Some(value), consuming and returning self.
Sourcepub fn with_extendee(self, value: impl Into<String>) -> Self
pub fn with_extendee(self, value: impl Into<String>) -> Self
Sets Self::extendee to Some(value), consuming and returning self.
Sourcepub fn with_default_value(self, value: impl Into<String>) -> Self
pub fn with_default_value(self, value: impl Into<String>) -> Self
Sets Self::default_value to Some(value), consuming and returning self.
Sourcepub fn with_oneof_index(self, value: i32) -> Self
pub fn with_oneof_index(self, value: i32) -> Self
Sets Self::oneof_index to Some(value), consuming and returning self.
Sourcepub fn with_json_name(self, value: impl Into<String>) -> Self
pub fn with_json_name(self, value: impl Into<String>) -> Self
Sets Self::json_name to Some(value), consuming and returning self.
Sourcepub fn with_proto3_optional(self, value: bool) -> Self
pub fn with_proto3_optional(self, value: bool) -> Self
Sets Self::proto3_optional to Some(value), consuming and returning self.