MessageOptions

Struct MessageOptions 

pub struct MessageOptions {
    pub message_set_wire_format: Option<bool>,
    pub no_standard_descriptor_accessor: Option<bool>,
    pub deprecated: Option<bool>,
    pub map_entry: Option<bool>,
    pub deprecated_legacy_json_field_conflicts: Option<bool>,
    pub features: MessageField<FeatureSet>,
    pub uninterpreted_option: Vec<UninterpretedOption>,
    /* private fields */
}

Fields

message_set_wire_format: Option<bool>

Set true to use the old proto1 MessageSet wire format for extensions. This is provided for backwards-compatibility with the MessageSet wire format. You should not use this for any other reason: It’s less efficient, has fewer features, and is more complicated.

The message must be defined exactly as follows: message Foo {

option message_set_wire_format = true;
extensions 4 to max;

} Note that the message cannot have any defined fields; MessageSets only have extensions.

All extensions of your type must be singular messages; e.g. they cannot be int32s, enums, or repeated messages.

Because this is an option, the above two restrictions are not enforced by the protocol compiler.

Field 1: message_set_wire_format

no_standard_descriptor_accessor: Option<bool>

Disables the generation of the standard “descriptor()” accessor, which can conflict with a field of the same name. This is meant to make migration from proto1 easier; new code should avoid fields named “descriptor”.

Field 2: no_standard_descriptor_accessor

deprecated: Option<bool>

Is this message deprecated? Depending on the target platform, this can emit Deprecated annotations for the message, or it will be completely ignored; in the very least, this is a formalization for deprecating messages.

Field 3: deprecated

map_entry: Option<bool>

Whether the message is an automatically generated map entry type for the maps field.

For maps fields:

map<KeyType, ValueType> map_field = 1;

The parsed descriptor looks like:

message MapFieldEntry {
    option map_entry = true;
    optional KeyType key = 1;
    optional ValueType value = 2;
}
repeated MapFieldEntry map_field = 1;

Implementations may choose not to generate the map_entry=true message, but use a native map in the target language to hold the keys and values. The reflection APIs in such implementations still need to work as if the field is a repeated message field.

NOTE: Do not set the option in .proto files. Always use the maps syntax instead. The option should only be implicitly set by the proto compiler parser.

Field 7: map_entry

deprecated_legacy_json_field_conflicts: Option<bool>

Enable the legacy handling of JSON field name conflicts. This lowercases and strips underscored from the fields before comparison in proto3 only. The new behavior takes json_name into account and applies to proto2 as well.

This should only be used as a temporary measure against broken builds due to the change in behavior for JSON field name conflicts.

TODO This is legacy behavior we plan to remove once downstream teams have had time to migrate.

Field 11: deprecated_legacy_json_field_conflicts

features: MessageField<FeatureSet>

Any features defined in the specific edition. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.

Field 12: features

uninterpreted_option: Vec<UninterpretedOption>

The parser stores options it doesn’t recognize here. See above.

Field 999: uninterpreted_option

Implementations

Source

impl MessageOptions

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.MessageOptions"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>