MethodOptions

Struct MethodOptions 

pub struct MethodOptions {
    pub deprecated: Option<bool>,
    pub idempotency_level: Option<IdempotencyLevel>,
    pub features: MessageField<FeatureSet, Inline<FeatureSet>>,
    pub uninterpreted_option: Vec<UninterpretedOption>,
    /* private fields */
}

Fields

deprecated: Option<bool>

Note: Field numbers 1 through 32 are reserved for Google’s internal RPC framework. We apologize for hoarding these numbers to ourselves, but we were already using them long before we decided to release Protocol Buffers.

Is this method deprecated? Depending on the target platform, this can emit Deprecated annotations for the method, or it will be completely ignored; in the very least, this is a formalization for deprecating methods.

Field 33: deprecated

idempotency_level: Option<IdempotencyLevel>

Field 34: idempotency_level

features: MessageField<FeatureSet, Inline<FeatureSet>>

Any features defined in the specific edition. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.

Field 35: features

uninterpreted_option: Vec<UninterpretedOption>

The parser stores options it doesn’t recognize here. See above.

Field 999: uninterpreted_option

Implementations

Source

impl MethodOptions

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.MethodOptions"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>

Source

impl MethodOptions

pub fn with_deprecated(self, value: bool) -> Self

Sets Self::deprecated to Some(value), consuming and returning self.

pub fn with_idempotency_level(self, value: impl Into<IdempotencyLevel>) -> Self

Sets Self::idempotency_level to Some(value), consuming and returning self.