pub struct UninterpretedOption {
pub name: Vec<NamePart>,
pub identifier_value: Option<String>,
pub positive_int_value: Option<u64>,
pub negative_int_value: Option<i64>,
pub double_value: Option<f64>,
pub string_value: Option<Vec<u8>>,
pub aggregate_value: Option<String>,
/* private fields */
}Expand description
A message representing a option the parser does not recognize. This only appears in options protos created by the compiler::Parser class. DescriptorPool resolves these when building Descriptor objects. Therefore, options protos in descriptor objects (e.g. returned by Descriptor::options(), or produced by Descriptor::CopyTo()) will never have UninterpretedOptions in them.
Fields
name: Vec<NamePart>Field 2: name
identifier_value: Option<String>The value of the uninterpreted option, in whatever type the tokenizer identified it as during parsing. Exactly one of these should be set.
Field 3: identifier_value
positive_int_value: Option<u64>Field 4: positive_int_value
negative_int_value: Option<i64>Field 5: negative_int_value
double_value: Option<f64>Field 6: double_value
string_value: Option<Vec<u8>>Field 7: string_value
aggregate_value: Option<String>Field 8: aggregate_value
Implementations