SymbolVisibility

Enum SymbolVisibility 

#[repr(i32)]
pub enum SymbolVisibility { VISIBILITY_UNSET = 0, VISIBILITY_LOCAL = 1, VISIBILITY_EXPORT = 2, }
Describes the ‘visibility’ of a symbol with respect to the proto import system. Symbols can only be imported when the visibility rules do not prevent it (ex: local symbols cannot be imported). Visibility modifiers can only set on message and enum as they are the only types available to be referenced from other files.

Variants



VISIBILITY_UNSET = 0



VISIBILITY_LOCAL = 1



VISIBILITY_EXPORT = 2