pub struct FeatureSupport {
pub edition_introduced: Option<Edition>,
pub edition_deprecated: Option<Edition>,
pub deprecation_warning: Option<String>,
pub edition_removed: Option<Edition>,
/* private fields */
}Expand description
Information about the support window of a feature.
Fields
edition_introduced: Option<Edition>The edition that this feature was first available in. In editions earlier than this one, the default assigned to EDITION_LEGACY will be used, and proto files will not be able to override it.
Field 1: edition_introduced
edition_deprecated: Option<Edition>The edition this feature becomes deprecated in. Using this after this edition may trigger warnings.
Field 2: edition_deprecated
deprecation_warning: Option<String>The deprecation warning text if this feature is used after the edition it was marked deprecated in.
Field 3: deprecation_warning
edition_removed: Option<Edition>The edition this feature is no longer available in. In editions after this one, the last default assigned will be used, and proto files will not be able to override it.
Field 4: edition_removed
Implementations
Sourceimpl FeatureSupport
impl FeatureSupport
Sourcepub fn with_edition_introduced(self, value: impl Into<Edition>) -> Self
pub fn with_edition_introduced(self, value: impl Into<Edition>) -> Self
Sets Self::edition_introduced to Some(value), consuming and returning self.
Sourcepub fn with_edition_deprecated(self, value: impl Into<Edition>) -> Self
pub fn with_edition_deprecated(self, value: impl Into<Edition>) -> Self
Sets Self::edition_deprecated to Some(value), consuming and returning self.
Sourcepub fn with_deprecation_warning(self, value: impl Into<String>) -> Self
pub fn with_deprecation_warning(self, value: impl Into<String>) -> Self
Sets Self::deprecation_warning to Some(value), consuming and returning self.
Sourcepub fn with_edition_removed(self, value: impl Into<Edition>) -> Self
pub fn with_edition_removed(self, value: impl Into<Edition>) -> Self
Sets Self::edition_removed to Some(value), consuming and returning self.