FeatureSupport

Struct FeatureSupport 

pub struct FeatureSupport {
    pub edition_introduced: Option<Edition>,
    pub edition_deprecated: Option<Edition>,
    pub deprecation_warning: Option<String>,
    pub edition_removed: Option<Edition>,
    /* private fields */
}
Information about the support window of a feature.

Fields

edition_introduced: Option<Edition>

The edition that this feature was first available in. In editions earlier than this one, the default assigned to EDITION_LEGACY will be used, and proto files will not be able to override it.

Field 1: edition_introduced

edition_deprecated: Option<Edition>

The edition this feature becomes deprecated in. Using this after this edition may trigger warnings.

Field 2: edition_deprecated

deprecation_warning: Option<String>

The deprecation warning text if this feature is used after the edition it was marked deprecated in.

Field 3: deprecation_warning

edition_removed: Option<Edition>

The edition this feature is no longer available in. In editions after this one, the last default assigned will be used, and proto files will not be able to override it.

Field 4: edition_removed

Implementations

Source

impl FeatureSupport

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.FieldOptions.FeatureSupport"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>