#[repr(i32)]pub enum Semantic {
NONE = 0,
SET = 1,
ALIAS = 2,
}Expand description
Represents the identified object’s effect on the element in the original .proto file.
Variants
NONE = 0
There is no effect or the effect is indescribable.
SET = 1
The element is set or otherwise mutated.
ALIAS = 2
An alias to the element is returned.
Implementations
Sourceimpl Semantic
impl Semantic
Sourcepub const None: Self = Self::NONE
pub const None: Self = Self::NONE
Idiomatic alias for Self::NONE; Debug prints the variant name.
Sourcepub const Alias: Self = Self::ALIAS
pub const Alias: Self = Self::ALIAS
Idiomatic alias for Self::ALIAS; Debug prints the variant name.