Semantic

#[repr(i32)]
pub enum Semantic { NONE = 0, SET = 1, ALIAS = 2, }
Represents the identified object’s effect on the element in the original .proto file.

Variants



NONE = 0

There is no effect or the effect is indescribable.



SET = 1

The element is set or otherwise mutated.



ALIAS = 2

An alias to the element is returned.