pub struct EnumDescriptorProto {
pub name: Option<String>,
pub value: Vec<EnumValueDescriptorProto>,
pub options: MessageField<EnumOptions, Inline<EnumOptions>>,
pub reserved_range: Vec<EnumReservedRange>,
pub reserved_name: Vec<String>,
pub visibility: Option<SymbolVisibility>,
/* private fields */
}Expand description
Describes an enum type.
Fields
name: Option<String>Field 1: name
value: Vec<EnumValueDescriptorProto>Field 2: value
options: MessageField<EnumOptions, Inline<EnumOptions>>Field 3: options
reserved_range: Vec<EnumReservedRange>Range of reserved numeric values. Reserved numeric values may not be used by enum values in the same enum declaration. Reserved ranges may not overlap.
Field 4: reserved_range
reserved_name: Vec<String>Reserved enum value names, which may not be reused. A given name may only be reserved once.
Field 5: reserved_name
visibility: Option<SymbolVisibility>Support for export and local keywords on enums.
Field 6: visibility
Implementations
Sourceimpl EnumDescriptorProto
impl EnumDescriptorProto
Sourcepub fn with_name(self, value: impl Into<String>) -> Self
pub fn with_name(self, value: impl Into<String>) -> Self
Sets Self::name to Some(value), consuming and returning self.
Sourcepub fn with_visibility(self, value: impl Into<SymbolVisibility>) -> Self
pub fn with_visibility(self, value: impl Into<SymbolVisibility>) -> Self
Sets Self::visibility to Some(value), consuming and returning self.