pub struct EnumOptions {
pub allow_alias: Option<bool>,
pub deprecated: Option<bool>,
pub deprecated_legacy_json_field_conflicts: Option<bool>,
pub features: MessageField<FeatureSet>,
pub uninterpreted_option: Vec<UninterpretedOption>,
/* private fields */
}Fields
allow_alias: Option<bool>Set this option to true to allow mapping different tag names to the same value.
Field 2: allow_alias
deprecated: Option<bool>Is this enum deprecated? Depending on the target platform, this can emit Deprecated annotations for the enum, or it will be completely ignored; in the very least, this is a formalization for deprecating enums.
Field 3: deprecated
deprecated_legacy_json_field_conflicts: Option<bool>Enable the legacy handling of JSON field name conflicts. This lowercases
and strips underscored from the fields before comparison in proto3 only.
The new behavior takes json_name into account and applies to proto2 as
well.
TODO Remove this legacy behavior once downstream teams have
had time to migrate.
Field 6: deprecated_legacy_json_field_conflicts
features: MessageField<FeatureSet>Any features defined in the specific edition. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.
Field 7: features
uninterpreted_option: Vec<UninterpretedOption>The parser stores options it doesn’t recognize here. See above.
Field 999: uninterpreted_option
Implementations