FieldOptions

Struct FieldOptions 

pub struct FieldOptions {
Show 14 fields pub ctype: Option<CType>, pub packed: Option<bool>, pub jstype: Option<JSType>, pub lazy: Option<bool>, pub unverified_lazy: Option<bool>, pub deprecated: Option<bool>, pub weak: Option<bool>, pub debug_redact: Option<bool>, pub retention: Option<OptionRetention>, pub targets: Vec<OptionTargetType>, pub edition_defaults: Vec<EditionDefault>, pub features: MessageField<FeatureSet>, pub feature_support: MessageField<FeatureSupport>, pub uninterpreted_option: Vec<UninterpretedOption>, /* private fields */
}

Fields

ctype: Option<CType>

NOTE: ctype is deprecated. Use features.(pb.cpp).string_type instead. The ctype option instructs the C++ code generator to use a different representation of the field than it normally would. See the specific options below. This option is only implemented to support use of [ctype=CORD] and [ctype=STRING] (the default) on non-repeated fields of type “bytes” in the open source release. TODO: make ctype actually deprecated.

Field 1: ctype

packed: Option<bool>

The packed option can be enabled for repeated primitive fields to enable a more efficient representation on the wire. Rather than repeatedly writing the tag and type for each element, the entire array is encoded as a single length-delimited blob. In proto3, only explicit setting it to false will avoid using packed encoding. This option is prohibited in Editions, but the repeated_field_encoding feature can be used to control the behavior.

Field 2: packed

jstype: Option<JSType>

The jstype option determines the JavaScript type used for values of the field. The option is permitted only for 64 bit integral and fixed types (int64, uint64, sint64, fixed64, sfixed64). A field with jstype JS_STRING is represented as JavaScript string, which avoids loss of precision that can happen when a large value is converted to a floating point JavaScript. Specifying JS_NUMBER for the jstype causes the generated JavaScript code to use the JavaScript “number” type. The behavior of the default option JS_NORMAL is implementation dependent.

This option is an enum to permit additional types to be added, e.g. goog.math.Integer.

Field 6: jstype

lazy: Option<bool>

Should this field be parsed lazily? Lazy applies only to message-type fields. It means that when the outer message is initially parsed, the inner message’s contents will not be parsed but instead stored in encoded form. The inner message will actually be parsed when it is first accessed.

This is only a hint. Implementations are free to choose whether to use eager or lazy parsing regardless of the value of this option. However, setting this option true suggests that the protocol author believes that using lazy parsing on this field is worth the additional bookkeeping overhead typically needed to implement it.

This option does not affect the public interface of any generated code; all method signatures remain the same. Furthermore, thread-safety of the interface is not affected by this option; const methods remain safe to call from multiple threads concurrently, while non-const methods continue to require exclusive access.

Note that lazy message fields are still eagerly verified to check ill-formed wireformat or missing required fields. Calling IsInitialized() on the outer message would fail if the inner message has missing required fields. Failed verification would result in parsing failure (except when uninitialized messages are acceptable).

Field 5: lazy

unverified_lazy: Option<bool>

unverified_lazy does no correctness checks on the byte stream. This should only be used where lazy with verification is prohibitive for performance reasons.

Field 15: unverified_lazy

deprecated: Option<bool>

Is this field deprecated? Depending on the target platform, this can emit Deprecated annotations for accessors, or it will be completely ignored; in the very least, this is a formalization for deprecating fields.

Field 3: deprecated

weak: Option<bool>

DEPRECATED. DO NOT USE! For Google-internal migration only. Do not use.

Field 10: weak

debug_redact: Option<bool>

Indicate that the field value should not be printed out when using debug formats, e.g. when the field contains sensitive credentials.

Field 16: debug_redact

retention: Option<OptionRetention>

Field 17: retention

targets: Vec<OptionTargetType>

Field 19: targets

edition_defaults: Vec<EditionDefault>

Field 20: edition_defaults

features: MessageField<FeatureSet>

Any features defined in the specific edition. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.

Field 21: features

feature_support: MessageField<FeatureSupport>

Field 22: feature_support

uninterpreted_option: Vec<UninterpretedOption>

The parser stores options it doesn’t recognize here. See above.

Field 999: uninterpreted_option

Implementations

Source

impl FieldOptions

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.FieldOptions"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>