pub struct FileDescriptorProto {Show 14 fields
pub name: Option<String>,
pub package: Option<String>,
pub dependency: Vec<String>,
pub public_dependency: Vec<i32>,
pub weak_dependency: Vec<i32>,
pub option_dependency: Vec<String>,
pub message_type: Vec<DescriptorProto>,
pub enum_type: Vec<EnumDescriptorProto>,
pub service: Vec<ServiceDescriptorProto>,
pub extension: Vec<FieldDescriptorProto>,
pub options: MessageField<FileOptions>,
pub source_code_info: MessageField<SourceCodeInfo>,
pub syntax: Option<String>,
pub edition: Option<Edition>,
/* private fields */
}Expand description
Describes a complete .proto file.
Fields
name: Option<String>file name, relative to root of source tree
Field 1: name
package: Option<String>e.g. “foo”, “foo.bar”, etc.
Field 2: package
dependency: Vec<String>Names of files imported by this file.
Field 3: dependency
public_dependency: Vec<i32>Indexes of the public imported files in the dependency list above.
Field 10: public_dependency
weak_dependency: Vec<i32>Indexes of the weak imported files in the dependency list. For Google-internal migration only. Do not use.
Field 11: weak_dependency
option_dependency: Vec<String>Names of files imported by this file purely for the purpose of providing option extensions. These are excluded from the dependency list above.
Field 15: option_dependency
message_type: Vec<DescriptorProto>All top-level definitions in this file.
Field 4: message_type
enum_type: Vec<EnumDescriptorProto>Field 5: enum_type
service: Vec<ServiceDescriptorProto>Field 6: service
extension: Vec<FieldDescriptorProto>Field 7: extension
options: MessageField<FileOptions>Field 8: options
source_code_info: MessageField<SourceCodeInfo>This field contains optional information about the original source code. You may safely remove this entire field without harming runtime functionality of the descriptors – the information is needed only by development tools.
Field 9: source_code_info
syntax: Option<String>The syntax of the proto file. The supported values are “proto2”, “proto3”, and “editions”.
If edition is present, this value must be “editions”.
WARNING: This field should only be used by protobuf plugins or special
cases like the proto compiler. Other uses are discouraged and
developers should rely on the protoreflect APIs for their client language.
Field 12: syntax
edition: Option<Edition>The edition of the proto file. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.
Field 14: edition
Implementations