pub struct OneofOptions {
pub features: MessageField<FeatureSet>,
pub uninterpreted_option: Vec<UninterpretedOption>,
/* private fields */
}Fields
features: MessageField<FeatureSet>Any features defined in the specific edition. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.
Field 1: features
uninterpreted_option: Vec<UninterpretedOption>The parser stores options it doesn’t recognize here. See above.
Field 999: uninterpreted_option
Implementations